..
    Copyright (C) 2020 Mojib Wali.

    invenio-config-iform is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Authors
=======

invenio module that adds I-Form configs.

- Cian Hughes <cian.hughes@dcu.ie>

Forked from https://github.com/tu-graz-library/invenio-theme-tugraz
